summaryrefslogtreecommitdiffstats
path: root/chrome/browser/extensions/api/dial/dial_api.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/extensions/api/dial/dial_api.h')
-rw-r--r--chrome/browser/extensions/api/dial/dial_api.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/chrome/browser/extensions/api/dial/dial_api.h b/chrome/browser/extensions/api/dial/dial_api.h
index 8a36044..74e284e 100644
--- a/chrome/browser/extensions/api/dial/dial_api.h
+++ b/chrome/browser/extensions/api/dial/dial_api.h
@@ -17,11 +17,11 @@ namespace extensions {
class DialRegistry;
// Dial API which is a ref-counted ProfileKeyedService that manages the DIAL
// registry. It takes care of creating the registry on the IO thread and
// is an observer of the registry. It makes sure devices events are sent out
// to extension listeners on the right thread.
-class DialAPI : public RefcountedProfileKeyedService,
+class DialAPI : public RefcountedBrowserContextKeyedService,
public EventRouter::Observer,
public DialRegistry::Observer {
public:
@@ -39,7 +39,7 @@ class DialAPI : public RefcountedProfileKeyedService,
private:
virtual ~DialAPI();
- // RefcountedProfileKeyedService:
+ // RefcountedBrowserContextKeyedService:
virtual void ShutdownOnUIThread() OVERRIDE;
// EventRouter::Observer:
@@ -17,11 +17,11 @@ namespace extensions {
class DialRegistry;
-// Dial API which is a ref-counted ProfileKeyedService that manages the DIAL
-// registry. It takes care of creating the registry on the IO thread and
-// is an observer of the registry. It makes sure devices events are sent out
+// Dial API which is a ref-counted BrowserContextKeyedService that manages
+// the DIAL registry. It takes care of creating the registry on the IO thread
+// and is an observer of the registry. It makes sure devices events are sent out
// to extension listeners on the right thread.